@@ -1,4 +1,5 @@
 from powerml.model.PowerML import PowerML
+from powerml.model.LLM import LLM
 from powerml.model.ForecastSequenceModel import ForecastSequenceModel
 from powerml.model.AutocompleteSQLModel import AutocompleteSQLModel
 from powerml.model.WriteEmailModel import WriteEmailModel
@@ -7,6 +8,7 @@ from powerml.model.CreateTopicsModel import CreateTopicsModel
 from powerml.model.ExtractTopicsModel import ExtractTopicsModel
 from powerml.model.FilterTopicsModel import FilterTopicsModel
 from powerml.model.QuestionAnswerModel import QuestionAnswerModel
+from powerml.model.ScoredModel import ScoredModel
 from powerml.filters.Filter import Filter
 from powerml.filters.TopicFilter import TopicFilter
 from powerml.filters.SQLFilter import SQLFilter
@@ -23,3 +25,5 @@ from powerml.generators.PrestoGenerator import PrestoGenerator
 from powerml.generators.EmailGenerator import EmailGenerator
 from powerml.generators.QuestionGenerator import QuestionGenerator
 from powerml.generators.ForecastGenerator import ForecastGenerator
+from powerml.prompt.ContextTemplate import ContextTemplate
+from powerml.prompt.ContextTemplateBuilder import ContextTemplateBuilder
