@@ -132,8 +132,7 @@ class PrestoGenerator(MenuGenerator):
             "This is a conversation where the customer asks for a different type of bread before finally ordering the following items:",
             "This is a conversation where the customer asks if the food is gluten-free before finally ordering the following items:",
             "This is a conversation where the customer asks if the food is vegan before finally ordering the following items:",
-            "This is a conversation where the customer asks if the food is organic before finally ordering the following items:"
-        ]
+            "This is a conversation where the customer asks if the food is organic before finally ordering the following items:"]
 
         generations = []
 
