@@ -1,4 +1,5 @@
 from powerml import PowerML
+from powerml.utils.constants import MAX_TEMPLATE_TOKENS
 import re
 from collections import Counter, defaultdict
 import random
@@ -8,9 +9,6 @@ import os
 import nltk
 from nltk.stem import WordNetLemmatizer
 
-from powerml.model.PowerML import MAX_TOTAL_TOKENS
-
-
 class CreateTopicsModel:
     '''
     This model removes duplicates and attempts to generate topics relevant
@@ -26,8 +24,6 @@ class CreateTopicsModel:
         # This is a hack to silence printed message on import
         sys.stdout = open(os.devnull, 'w')
         sys.stderr = open(os.devnull, 'w')
-        from transformers import GPT2Tokenizer
-        from transformers.utils import logging
         nltk.download('wordnet')
         self.lemmatizer = WordNetLemmatizer()
         sys.stdout = sys.__stdout__
@@ -35,15 +31,12 @@ class CreateTopicsModel:
 
         if random_seed is not None:
             random.seed(random_seed)
-        self.model = PowerML(config)
-        self.create_model_name = "unblocked/create-topics/v2"
+        self.model = PowerML(config, "unblocked/create-topics/v2")
         self.messages = []
         self.num_subsamples = num_subsamples
         self.sample_size = 20
         self.max_output_tokens = max_output_tokens
         self.memo_topics = {}
-        self.tokenizer = GPT2Tokenizer.from_pretrained("gpt2")
-        logging.set_verbosity(40)
 
     def fit(self, documents, topic_type):
         """
@@ -89,7 +82,7 @@ class CreateTopicsModel:
                 queue, sample_index, self.sample_size)
             prompt = self.__add_examples(examples, prompt)
             output = self.model.predict(
-                prompt, max_tokens=self.max_output_tokens, temperature=0.7, model=self.create_model_name)
+                prompt, max_tokens=self.max_output_tokens, temperature=0.7)
             topics = self.__parse_output(output)
             topic_counter.update(topics)
             sorted_topics = self.__sort_topics(topic_counter)
@@ -99,7 +92,7 @@ class CreateTopicsModel:
         return topics
 
     def __count_tokens(self, string):
-        return len(self.tokenizer(string)['input_ids'])
+        return len(string) // 4
 
     def __prompt_format(self, topic_type):
         prompt_dict = {"{{topic_type}}": topic_type}
@@ -108,7 +101,7 @@ class CreateTopicsModel:
             prompt_dict[key] = ""
         return prompt_dict
 
-    def __add_examples(self, examples, prompt, max_total_tokens=MAX_TOTAL_TOKENS):
+    def __add_examples(self, examples, prompt, max_total_tokens=MAX_TEMPLATE_TOKENS):
         prompt_dict = prompt
         for i, example in enumerate(examples):
             key = "{{example" + str(i + 1) + "}}"
@@ -135,7 +128,7 @@ class CreateTopicsModel:
         end_index = min(start_index + sample_size, self.num_samples)
         for index in range(start_index, end_index):
             token_count += self.__count_tokens(data[index])
-            if token_count > MAX_TOTAL_TOKENS:
+            if token_count > MAX_TEMPLATE_TOKENS:
                 return examples, index
             examples.append(data[index])
         return examples, index
