@@ -8,8 +8,7 @@ logger = logging.getLogger(__name__)
 class ExtractMenuItemsModel:
     def __init__(self, config={}, max_output_tokens=32, temperature=0.0, threshold=28.92):
         self.max_output_tokens = max_output_tokens
-        self.model = PowerML(config)
-        self.model_name = "presto/del-taco-menu/v2"
+        self.model = PowerML(config, "presto/del-taco-menu/v2")
         self.temperature = temperature
         self.threshold = threshold
         self.examples = []
@@ -43,7 +42,6 @@ class ExtractMenuItemsModel:
             prompt,
             max_tokens=self.max_output_tokens,
             temperature=self.temperature,
-            model=self.model_name,
         )
         return self.__post_process(output, probability)
 
