@@ -10,8 +10,7 @@ class ForecastSequenceModel:
                  config={},
                  max_output_tokens=256,
                  ):
-        self.model = PowerML(config)
-        self.model_name = "inference-io/forecast-wondery/v2"
+        self.model = PowerML(config, "inference-io/forecast-wondery/v2")
         self.max_output_tokens = max_output_tokens
 
     def fit(self, examples=[]):
@@ -51,7 +50,7 @@ class ForecastSequenceModel:
             "{{title}}": title
         }
         output = self.model.predict(
-            prompt, max_tokens=self.max_output_tokens, temperature=0.7, model=self.model_name)
+            prompt, max_tokens=self.max_output_tokens, temperature=0.7)
         return self.__post_process(output)
 
     def __post_process(self, output):
