@@ -1,38 +1,34 @@
 import io
-from typing import Tuple
+from typing import List, Tuple
 import jsonlines
 from powerml.utils.run_ai import query_powerml, mutation_powerml_train, query_powerml_with_probability
 import logging
 
 logger = logging.getLogger(__name__)
 
-MAX_TEMPLATE_TOKENS = 3072
-MAX_TOTAL_TOKENS = 4097
-
 
 class PowerML:
     '''
-    hex_data = get_data()
-    powerml = PowerML()
-    completion = powerml.predict(model="hex/model_for_hex", prompt)
-    powerml.fit(hex_data, model="hex/model_for_hex")
+    Each instance of the PowerML class represents an LLM 
+    accessible through the PowerML API.
     '''
 
-    def __init__(self, config={}):
+    def __init__(self, config={}, model="text-davinci-003"):
         self.config = config
-        self.current_model = "text-davinci-003"
+        self.current_model = model
+        self.foundational_model = model 
 
     def predict(self,
                 prompt,
-                model: str = None,
                 stop: str = "",
                 max_tokens: int = 128,
                 temperature: float = 0.0,
                 ) -> str:
-        if model == "" or model is None:
-            model = self.current_model
+        """
+        Prompt the model to return a completion
+        """
+        model = self.current_model
         logger.debug("Predict using model: " + model)
-        # if the model is one of our models, then hit our api
         return query_powerml(prompt,
                              max_tokens=max_tokens,
                              model=model,
@@ -43,15 +39,15 @@ class PowerML:
 
     def predict_with_probability(self,
                                  prompt,
-                                 model: str = None,
                                  stop: str = "",
                                  max_tokens: int = 128,
                                  temperature: float = 0.0,
                                  ) -> Tuple[str, float]:
-        if model == "" or model is None:
-            model = self.current_model
+        """
+        Prompt the model to return a completion and the confidence of that completion
+        """
+        model = self.current_model
         logger.debug("Predict using model: " + model)
-        # if the model is one of our models, then hit our api
         return query_powerml_with_probability(prompt,
                                               max_tokens=max_tokens,
                                               model=model,
@@ -61,15 +57,31 @@ class PowerML:
                                               )
 
     def fit(self,
-            data: list[str],
-            model: str = None,
+            data: List[str],
             name: str = None,
             is_public: bool = False):
-        if model == "" or model is None:
-            model = self.current_model
-        logger.debug("Fit using model: " + model)
+        """
+        Finetune a model 
+        """
+        # TODO: fit and set_prompt only works on foundational models
+        logger.debug("Fit using model: " + self.foundational_model)
         dataset = self.__make_dataset_string(data)
-        response = mutation_powerml_train(dataset, name, model, is_public, self.config)
+        response = mutation_powerml_train(dataset, name, self.foundational_model, is_public, self.config)
+        model_details = response.json()['model']
+        self.current_model = model_details["model_name"]
+        return model_details
+
+    def set_prompt(self,
+            prompt: str,
+            name: str = None,
+            is_public: bool = False):
+        """
+        Set the model's prompt
+        """
+        # TODO: fit and set_prompt only works on foundational models
+        logger.debug("Fit using model: " + self.foundational_model)
+        dataset = self.__make_dataset_string([prompt])
+        response = mutation_powerml_train(dataset, name, self.foundational_model, is_public, self.config)
         model_details = response.json()['model']
         self.current_model = model_details["model_name"]
         return model_details
