@@ -1,4 +1,5 @@
 
+from typing import List
 from powerml import PowerML
 import re
 import logging
@@ -11,12 +12,11 @@ class QuestionAnswerModel:
                  config={},
                  max_output_tokens=256,
                  ):
-        self.model = PowerML(config)
-        self.model_name = "quizlet/questions/v3"
+        self.model = PowerML(config, "quizlet/questions/v3")
         self.max_output_tokens = max_output_tokens
 
     def fit(self,
-            examples: list[dict]):
+            examples: List[dict]):
         """
         Parameters
         ----------
@@ -58,7 +58,7 @@ class QuestionAnswerModel:
             "{{examples}}": examples_string,
         }
         output = self.model.predict(
-            prompt, max_tokens=self.max_output_tokens, temperature=0.7, model=self.model_name)
+            prompt, max_tokens=self.max_output_tokens, temperature=0.7)
         return self.__post_process(output)
 
     def __post_process(self, output):
