@@ -7,8 +7,7 @@ logger = logging.getLogger(__name__)
 class WriteEmailModel:
     def __init__(self, config={}, max_output_tokens=512, temperature=0.7):
         self.max_output_tokens = max_output_tokens
-        self.model = PowerML(config)
-        self.model_name = "stensul/email-copy/v2"
+        self.model = PowerML(config, "stensul/email-copy/v2")
         self.temperature = temperature
 
     def fit(self, examples):
@@ -39,6 +38,5 @@ class WriteEmailModel:
             prompt,
             max_tokens=self.max_output_tokens,
             temperature=self.temperature,
-            model=self.model_name
         )
         return output
